@@ -19,10 +19,13 @@
 ##
 
 APP_NAME = 'PyZendesk'
-APP_VERSION = '0.4.0'
+APP_VERSION = '0.4.1'
 APP_DESCRIPTION = 'API for Zendesk'
-APP_ID = 'pyzendesk.muflone.com'
-APP_URL = 'https://www.muflone.com/pyzendesk/'
+APP_DOMAIN = 'pyzendesk'
+APP_ID = f'{APP_DOMAIN}.muflone.com'
 APP_AUTHOR = 'Fabio Castelli'
 APP_AUTHOR_EMAIL = 'muflone@muflone.com'
-APP_COPYRIGHT = 'Copyright 2021-2022 %s' % APP_AUTHOR
+APP_COPYRIGHT = f'Copyright 2021-2022 {APP_AUTHOR}'
+URL_AUTHOR = 'http://www.muflone.com/'
+URL_APPLICATION = f'{URL_AUTHOR}{APP_DOMAIN}/'
+URL_SOURCES = f'https://github.com/muflone/{APP_DOMAIN}/'
